package com.doc.biz.controller;

import com.doc.biz.domain.DocActor;
import com.doc.biz.service.IDocActorService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档协作Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档协作")
@RestController
@RequestMapping("/biz/actor")
public class DocActorController extends BaseController {
    @Resource
    private IDocActorService docActorService;

    /**
     * 查询文档协作列表
     */
    @ApiOperation("查询文档协作列表")
    //@PreAuthorize("@ss.hasPermi('biz:actor:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocActor docActor) {
        startPage();
        List<DocActor> list = docActorService.selectDocActorList(docActor);
        return getDataTable(list);
    }

    /**
     * 导出文档协作列表
     */
    @ApiOperation("导出文档协作列表")
    //@PreAuthorize("@ss.hasPermi('biz:actor:export')")
    @Log(title = "文档协作", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocActor docActor) {
        List<DocActor> list = docActorService.selectDocActorList(docActor);
        ExcelUtil<DocActor> util = new ExcelUtil<DocActor>(DocActor.class);
        util.exportExcel(response, list, "文档协作数据");
    }

    /**
     * 获取文档协作详细信息
     */
    @ApiOperation("获取文档协作详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:actor:query')")
    @GetMapping(value = "/{autoId}")
    public AjaxResult getInfo(@PathVariable("autoId") Long autoId) {
        return success(docActorService.selectDocActorByAutoId(autoId));
    }

    /**
     * 新增文档协作
     */
    @ApiOperation("新增文档协作")
    //@PreAuthorize("@ss.hasPermi('biz:actor:add')")
    @Log(title = "文档协作", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocActor docActor) {
        return toAjax(docActorService.insertDocActor(docActor));
    }

    /**
     * 修改文档协作
     */
    @ApiOperation("修改文档协作")
    //@PreAuthorize("@ss.hasPermi('biz:actor:edit')")
    @Log(title = "文档协作", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocActor docActor) {
        return toAjax(docActorService.updateDocActor(docActor));
    }

    /**
     * 删除文档协作
     */
    @ApiOperation("删除文档协作")
    //@PreAuthorize("@ss.hasPermi('biz:actor:remove')")
    @Log(title = "文档协作", businessType = BusinessType.DELETE)
    @DeleteMapping("/{autoIds}")
    public AjaxResult remove(@PathVariable Long[] autoIds) {
        return toAjax(docActorService.deleteDocActorByAutoIds(autoIds));
    }
}
