package com.doc.biz.controller;

import com.doc.biz.domain.DocFavorite;
import com.doc.biz.service.IDocDirService;
import com.doc.biz.service.IDocFavoriteService;
import com.doc.biz.service.IDocInfoService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文件收藏Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文件收藏")
@RestController
@RequestMapping("/biz/favorite")
public class DocFavoriteController extends BaseController {
    @Resource
    private IDocFavoriteService docFavoriteService;
    @Resource
    private IDocInfoService docInfoService;
    @Resource
    private IDocDirService docDirService;

    /**
     * 查询文件收藏列表
     */
    @ApiOperation("查询文件收藏列表")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocFavorite docFavorite) {
        startPage();
        List<DocFavorite> list = docFavoriteService.selectDocFavoriteList(docFavorite);
        return getDataTable(list);
    }

    /**
     * 查询文件收藏列表
     */
    @ApiOperation("根据标签ID查询列表")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:list')")
    @GetMapping("/listByLabelId")
    public List<DocFavorite> listByLabelId(@ApiParam(value = "标签ID", required = true) @RequestParam Long labelId) {
        DocFavorite docFavorite = new DocFavorite();
        docFavorite.setLabelId(labelId);
        List<DocFavorite> list = docFavoriteService.selectDocFavoriteList(docFavorite);
        for (DocFavorite favorite : list) {
            if ("Y".equals(favorite.getIsFolder())) {
                favorite.setDocDir(docDirService.selectDocDirByDirId(favorite.getRelaId()));
            } else {
                favorite.setDocInfo(docInfoService.selectDocInfoByDocId(favorite.getRelaId()));
            }
        }
        return list;
    }

    /**
     * 导出文件收藏列表
     */
    @ApiOperation("导出文件收藏列表")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:export')")
    @Log(title = "文件收藏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocFavorite docFavorite) {
        List<DocFavorite> list = docFavoriteService.selectDocFavoriteList(docFavorite);
        ExcelUtil<DocFavorite> util = new ExcelUtil<DocFavorite>(DocFavorite.class);
        util.exportExcel(response, list, "文件收藏数据");
    }

    /**
     * 获取文件收藏详细信息
     */
    @ApiOperation("获取文件收藏详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:query')")
    @GetMapping(value = "/{favoriteId}")
    public AjaxResult getInfo(@PathVariable("favoriteId") Long favoriteId) {
        return success(docFavoriteService.selectDocFavoriteByFavoriteId(favoriteId));
    }

    /**
     * 新增文件收藏
     */
    @ApiOperation("新增文件收藏")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:add')")
    @Log(title = "文件收藏", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocFavorite docFavorite) {
        return toAjax(docFavoriteService.insertDocFavorite(docFavorite));
    }

    /**
     * 修改文件收藏
     */
    @ApiOperation("修改文件收藏")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:edit')")
    @Log(title = "文件收藏", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocFavorite docFavorite) {
        return toAjax(docFavoriteService.updateDocFavorite(docFavorite));
    }

    /**
     * 删除文件收藏
     */
    @ApiOperation("删除文件收藏")
    //@PreAuthorize("@ss.hasPermi('biz:favorite:remove')")
    @Log(title = "文件收藏", businessType = BusinessType.DELETE)
    @DeleteMapping("/{favoriteIds}")
    public AjaxResult remove(@PathVariable Long[] favoriteIds) {
        return toAjax(docFavoriteService.deleteDocFavoriteByFavoriteIds(favoriteIds));
    }
}
