package com.doc.biz.controller;

import com.doc.biz.domain.DocShare;
import com.doc.biz.service.IDocShareService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文档分享Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文档分享")
@RestController
@RequestMapping("/biz/share")
public class DocShareController extends BaseController {
    @Resource
    private IDocShareService docShareService;

    /**
     * 查询文档分享列表
     */
    @ApiOperation("查询文档分享列表")
    //@PreAuthorize("@ss.hasPermi('biz:share:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocShare docShare) {
        startPage();
        List<DocShare> list = docShareService.selectDocShareList(docShare);
        return getDataTable(list);
    }

    /**
     * 导出文档分享列表
     */
    @ApiOperation("导出文档分享列表")
    //@PreAuthorize("@ss.hasPermi('biz:share:export')")
    @Log(title = "文档分享", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocShare docShare) {
        List<DocShare> list = docShareService.selectDocShareList(docShare);
        ExcelUtil<DocShare> util = new ExcelUtil<DocShare>(DocShare.class);
        util.exportExcel(response, list, "文档分享数据");
    }

    /**
     * 获取文档分享详细信息
     */
    @ApiOperation("获取文档分享详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:share:query')")
    @GetMapping(value = "/{shareId}")
    public AjaxResult getInfo(@PathVariable("shareId") Long shareId) {
        return success(docShareService.selectDocShareByShareId(shareId));
    }

    /**
     * 新增文档分享
     */
    @ApiOperation("新增文档分享")
    //@PreAuthorize("@ss.hasPermi('biz:share:add')")
    @Log(title = "文档分享", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocShare docShare) {
        return toAjax(docShareService.insertDocShare(docShare));
    }

    /**
     * 修改文档分享
     */
    @ApiOperation("修改文档分享")
    //@PreAuthorize("@ss.hasPermi('biz:share:edit')")
    @Log(title = "文档分享", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocShare docShare) {
        return toAjax(docShareService.updateDocShare(docShare));
    }

    /**
     * 删除文档分享
     */
    @ApiOperation("删除文档分享")
    //@PreAuthorize("@ss.hasPermi('biz:share:remove')")
    @Log(title = "文档分享", businessType = BusinessType.DELETE)
    @DeleteMapping("/{shareIds}")
    public AjaxResult remove(@PathVariable Long[] shareIds) {
        return toAjax(docShareService.deleteDocShareByShareIds(shareIds));
    }
}
