package com.doc.biz.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.doc.biz.domain.DocDirUser;
import com.doc.biz.mapper.DocDirUserMapper;
import com.doc.biz.service.IDocDirUserService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 组织目录成员Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocDirUserServiceImpl implements IDocDirUserService {
    @Resource
    private DocDirUserMapper docDirUserMapper;

    /**
     * 查询组织目录成员
     *
     * @param autoId 组织目录成员主键
     * @return 组织目录成员
     */
    @Override
    public DocDirUser selectDocDirUserByAutoId(Long autoId) {
        return docDirUserMapper.selectDocDirUserByAutoId(autoId);
    }

    /**
     * 查询组织目录成员列表
     *
     * @param docDirUser 组织目录成员
     * @return 组织目录成员
     */
    @Override
    public List<DocDirUser> selectDocDirUserList(DocDirUser docDirUser) {
        return docDirUserMapper.selectDocDirUserList(docDirUser);
    }

    /**
     * 新增组织目录成员
     *
     * @param docDirUser 组织目录成员
     * @return 结果
     */
    @Override
    public int insertDocDirUser(DocDirUser docDirUser) {
        docDirUser.setCreateTime(DateUtils.getNowDate());
        return docDirUserMapper.insertDocDirUser(docDirUser);
    }

    /**
     * 修改组织目录成员
     *
     * @param docDirUser 组织目录成员
     * @return 结果
     */
    @Override
    public int updateDocDirUser(DocDirUser docDirUser) {
        docDirUser.setUpdateTime(DateUtils.getNowDate());
        return docDirUserMapper.updateDocDirUser(docDirUser);
    }

    /**
     * 批量删除组织目录成员
     *
     * @param autoIds 需要删除的组织目录成员主键
     * @return 结果
     */
    @Override
    public int deleteDocDirUserByAutoIds(Long[] autoIds) {
        return docDirUserMapper.deleteDocDirUserByAutoIds(autoIds);
    }

    /**
     * 删除组织目录成员信息
     *
     * @param autoId 组织目录成员主键
     * @return 结果
     */
    @Override
    public int deleteDocDirUserByAutoId(Long autoId) {
        return docDirUserMapper.deleteDocDirUserByAutoId(autoId);
    }

    /**
     * 根据目录ID删除用户
     *
     * @param dirId 目录ID
     */
    @Override
    public void deleteDocDirUserByDirId(Long dirId) {
        QueryWrapper<DocDirUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("dir_id", dirId);
        docDirUserMapper.delete(queryWrapper);
    }
}
