package com.doc.biz.service.impl;

import com.doc.biz.domain.DocFavoriteLabel;
import com.doc.biz.mapper.DocFavoriteLabelMapper;
import com.doc.biz.service.IDocFavoriteLabelService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文件收藏标签Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocFavoriteLabelServiceImpl implements IDocFavoriteLabelService {
    @Resource
    private DocFavoriteLabelMapper docFavoriteLabelMapper;

    /**
     * 查询文件收藏标签
     *
     * @param labelId 文件收藏标签主键
     * @return 文件收藏标签
     */
    @Override
    public DocFavoriteLabel selectDocFavoriteLabelByLabelId(Long labelId) {
        return docFavoriteLabelMapper.selectDocFavoriteLabelByLabelId(labelId);
    }

    /**
     * 查询文件收藏标签列表
     *
     * @param docFavoriteLabel 文件收藏标签
     * @return 文件收藏标签
     */
    @Override
    public List<DocFavoriteLabel> selectDocFavoriteLabelList(DocFavoriteLabel docFavoriteLabel) {
        return docFavoriteLabelMapper.selectDocFavoriteLabelList(docFavoriteLabel);
    }

    /**
     * 新增文件收藏标签
     *
     * @param docFavoriteLabel 文件收藏标签
     * @return 结果
     */
    @Override
    public int insertDocFavoriteLabel(DocFavoriteLabel docFavoriteLabel) {
        docFavoriteLabel.setCreateTime(DateUtils.getNowDate());
        return docFavoriteLabelMapper.insertDocFavoriteLabel(docFavoriteLabel);
    }

    /**
     * 修改文件收藏标签
     *
     * @param docFavoriteLabel 文件收藏标签
     * @return 结果
     */
    @Override
    public int updateDocFavoriteLabel(DocFavoriteLabel docFavoriteLabel) {
        docFavoriteLabel.setUpdateTime(DateUtils.getNowDate());
        return docFavoriteLabelMapper.updateDocFavoriteLabel(docFavoriteLabel);
    }

    /**
     * 批量删除文件收藏标签
     *
     * @param labelIds 需要删除的文件收藏标签主键
     * @return 结果
     */
    @Override
    public int deleteDocFavoriteLabelByLabelIds(Long[] labelIds) {
        return docFavoriteLabelMapper.deleteDocFavoriteLabelByLabelIds(labelIds);
    }

    /**
     * 删除文件收藏标签信息
     *
     * @param labelId 文件收藏标签主键
     * @return 结果
     */
    @Override
    public int deleteDocFavoriteLabelByLabelId(Long labelId) {
        return docFavoriteLabelMapper.deleteDocFavoriteLabelByLabelId(labelId);
    }
}
