package com.doc.biz.service.impl;

import com.doc.biz.domain.DocInfo;
import com.doc.biz.mapper.DocInfoMapper;
import com.doc.biz.service.IDocInfoService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文件基本信息表Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocInfoServiceImpl implements IDocInfoService {
    @Resource
    private DocInfoMapper docInfoMapper;

    /**
     * 查询文件基本信息表
     *
     * @param docId 文件基本信息表主键
     * @return 文件基本信息表
     */
    @Override
    public DocInfo selectDocInfoByDocId(Long docId) {
        return docInfoMapper.selectDocInfoByDocId(docId);
    }

    /**
     * 查询文件基本信息表列表
     *
     * @param docInfo 文件基本信息表
     * @return 文件基本信息表
     */
    @Override
    public List<DocInfo> selectDocInfoList(DocInfo docInfo) {
        return docInfoMapper.selectDocInfoList(docInfo);
    }

    /**
     * 新增文件基本信息表
     *
     * @param docInfo 文件基本信息表
     * @return 结果
     */
    @Override
    public int insertDocInfo(DocInfo docInfo) {
        docInfo.setCreateTime(DateUtils.getNowDate());
        return docInfoMapper.insertDocInfo(docInfo);
    }

    /**
     * 修改文件基本信息表
     *
     * @param docInfo 文件基本信息表
     * @return 结果
     */
    @Override
    public int updateDocInfo(DocInfo docInfo) {
        docInfo.setUpdateTime(DateUtils.getNowDate());
        return docInfoMapper.updateDocInfo(docInfo);
    }

    /**
     * 批量删除文件基本信息表
     *
     * @param docIds 需要删除的文件基本信息表主键
     * @return 结果
     */
    @Override
    public int deleteDocInfoByDocIds(Long[] docIds) {
        return docInfoMapper.deleteDocInfoByDocIds(docIds);
    }

    /**
     * 删除文件基本信息表信息
     *
     * @param docId 文件基本信息表主键
     * @return 结果
     */
    @Override
    public int deleteDocInfoByDocId(Long docId) {
        return docInfoMapper.deleteDocInfoByDocId(docId);
    }
}
