package com.doc.biz.service.impl;

import com.doc.biz.domain.DocTransfer;
import com.doc.biz.mapper.DocTransferMapper;
import com.doc.biz.service.IDocTransferService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文件传输Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocTransferServiceImpl implements IDocTransferService {
    @Resource
    private DocTransferMapper docTransferMapper;

    /**
     * 查询文件传输
     *
     * @param tranId 文件传输主键
     * @return 文件传输
     */
    @Override
    public DocTransfer selectDocTransferByTranId(Long tranId) {
        return docTransferMapper.selectDocTransferByTranId(tranId);
    }

    /**
     * 查询文件传输列表
     *
     * @param docTransfer 文件传输
     * @return 文件传输
     */
    @Override
    public List<DocTransfer> selectDocTransferList(DocTransfer docTransfer) {
        return docTransferMapper.selectDocTransferList(docTransfer);
    }

    /**
     * 新增文件传输
     *
     * @param docTransfer 文件传输
     * @return 结果
     */
    @Override
    public int insertDocTransfer(DocTransfer docTransfer) {
        docTransfer.setCreateTime(DateUtils.getNowDate());
        return docTransferMapper.insertDocTransfer(docTransfer);
    }

    /**
     * 修改文件传输
     *
     * @param docTransfer 文件传输
     * @return 结果
     */
    @Override
    public int updateDocTransfer(DocTransfer docTransfer) {
        docTransfer.setUpdateTime(DateUtils.getNowDate());
        return docTransferMapper.updateDocTransfer(docTransfer);
    }

    /**
     * 批量删除文件传输
     *
     * @param tranIds 需要删除的文件传输主键
     * @return 结果
     */
    @Override
    public int deleteDocTransferByTranIds(Long[] tranIds) {
        return docTransferMapper.deleteDocTransferByTranIds(tranIds);
    }

    /**
     * 删除文件传输信息
     *
     * @param tranId 文件传输主键
     * @return 结果
     */
    @Override
    public int deleteDocTransferByTranId(Long tranId) {
        return docTransferMapper.deleteDocTransferByTranId(tranId);
    }
}
